@@ -24,9 +24,10 @@ from abc import ABC, abstractmethod
 from types import MappingProxyType
 from logging import Logger
 from functools import wraps, partial
+from collections import defaultdict
 from typing import (
     Any, TypeVar, Optional, Tuple, Mapping, Iterable, ClassVar, Union,
-    Callable, FrozenSet, cast, MutableMapping, TYPE_CHECKING, Dict
+    Callable, FrozenSet, cast, MutableMapping, TYPE_CHECKING, Dict,
 )
 
 import h5py
@@ -37,6 +38,7 @@ from nanoutils import Literal, TypedDict, set_docstring
 
 from ..type_hints import ArrayLike
 from ..functions.charge_utils import update_charge, get_net_charge, ChargeError
+from ..functions.cp2k_utils import UNIT_MAP_REVERSED
 
 if TYPE_CHECKING:
     from pandas.core.generic import NDFrame
@@ -408,6 +410,15 @@ class ParamMappingABC(AbstractDataClass, ABC):
         self.param.loc[idx, param_idx] = value
         return idx
 
+    def set_n_columns(self, n: int) -> None:
+        if len(self.param.columns) != 1:
+            raise ValueError
+        for i in range(1, n):
+            self.param[i] = self.param[0]
+            self.param_old[i] = self.param_old[0]
+            for j in self.metadata.columns.levels[1]:
+                self.metadata[i, j] = self.metadata[0, j]
+
     @abstractmethod
     def identify_move(self, param_idx: int) -> Tuple[Tup3, float, float]:
         """Identify the to-be moved parameter and the size of the move.
@@ -556,6 +567,24 @@ class ParamMappingABC(AbstractDataClass, ABC):
             ret[key][i]['unit'] = unit or None
         return ret
 
+    def get_cp2k_dicts(self) -> list[defaultdict[str, pd.DataFrame]]:
+        """Get dictionaries with CP2K parameters that are parsable by QMFlows."""
+        ret = []
+        df_template = pd.DataFrame(columns=["param", "unit"], dtype=object)
+        for i, series in self.param.items():
+            dct: defaultdict[str, pd.DataFrame] = defaultdict(df_template.copy)
+            visited = set()
+            for (k, param, atom), v in series.items():
+                visited_key = (k, param)
+                if visited_key not in visited:
+                    unit = self.metadata.at[(k, param, atom), (i, "unit")] or None
+                    visited.add(visited_key)
+                    dct[k].at[param, "param"] = param
+                    dct[k].at[param, "unit"] = UNIT_MAP_REVERSED.get(unit, unit)
+                dct[k].at[param, atom] = v
+            ret.append(dct)
+        return ret
+
 
 MOVE_RANGE = np.array([[
     0.900, 0.905, 0.910, 0.915, 0.920, 0.925, 0.930, 0.935, 0.940,
@@ -682,9 +711,13 @@ class ParamMapping(ParamMappingABC):
                     key_list = [(*key, i) for i in include]
                     self.param.loc[key_list] = self.param.loc[key_list, i].values[..., None]
                 else:
-                    self.param.loc[key, :] = self.param.loc[key, i].values[..., None]
+                    self.param.loc[key] = self.param.loc[key, i].values[..., None]
 
             if ret is not None:
                 self.param[:] = param_backup
+                if exclude is not None:
+                    ret.atoms = self.param.loc[key, :].index.difference(exclude)
+                else:
+                    ret.atoms = self.param.loc[key, :].index
                 return ret
         return None
