@@ -95,13 +95,10 @@ def dict_to_armc(input_dict: MainMapping) -> Tuple[MonteCarloABC, RunDict]:
     phi = get_phi(dct['phi'])
     package, mol_list = get_package(dct['job'], phi.phi)
     param, _param, _param_frozen, validation_dict = get_param(dct['param'])
+    if len(mol_list) > 1:
+        param.set_n_columns(len(mol_list))
     mc, run_kwargs = get_armc(dct['monte_carlo'], package, param, phi, mol_list)
 
-    # Update the job Settings
-    if _param_frozen is not None:
-        package.update_settings(list(prm_iter(_param_frozen)), new_keys=True)
-    package.update_settings(list(prm_iter(_param)), new_keys=True)
-
     # Handle psf stuff
     psf_list: Optional[List[PSFContainer]] = get_psf(dct['psf'], mol_list)
     run_kwargs['psf'] = psf_list
@@ -126,10 +123,14 @@ def dict_to_armc(input_dict: MainMapping) -> Tuple[MonteCarloABC, RunDict]:
     validate_constraints(param, enforce_constraints=validation_dict['enforce_constraints'])
     param._net_charge_to_integer()
 
+    # Sort the index
     mc.param.param.sort_index(inplace=True)
     mc.param.param_old.sort_index(inplace=True)
     mc.param.metadata.sort_index(inplace=True)
 
+    # Update the job settings
+    mc.package_manager.update_settings(mc.param.get_cp2k_dicts())
+
     # Add PES evaluators
     pes = get_pes(dct['pes'], len(mol_list))
     for name, kwargs in pes.items():
@@ -252,9 +253,6 @@ def _guess_param(mc: MonteCarloABC, prm: dict,
         prm_dict['param'] = param
         seq.append((k, prm_dict))
 
-    # Update the constant parameters
-    package.update_settings(seq, new_keys=True)
-
     # Update the variable parameters
     metadata = {'min': -np.inf, 'max': np.inf, 'count': 0, 'guess': True}
     _prm = mc.param.param
@@ -762,11 +760,10 @@ def update_count(param, psf=None, mol=None):  # noqa: E302
     index = param.metadata.index
     prm_count_list = [param.metadata[i, 'count'] for i in param.metadata.columns.levels[0]]
     at_sequence = [atoms.split() for *_, atoms in index]
-    for count in count_iter:
+    for prm_count, count in zip(prm_count_list, count_iter):
         data = get_atom_count(at_sequence, count)
         series = pd.Series({k: v for k, v in zip(index, data) if v is not None}, name='unit')
-        for prm_count in prm_count_list:
-            prm_count.update(series)
+        prm_count.update(series)
 
 
 def _assign_residues(plams_mol: Molecule, res_list: Iterable[Iterable[int]]) -> None:
